/*
 
 KeyField.h   Copyright  2004 Audun Wilhelmsen
 ---------------------------------------------------------------
 The control and cell for editing Key Combinations.
 ---------------------------------------------------------------
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation; either version 2
 of the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
 
 */

#import <Cocoa/Cocoa.h>
#import "KeyCombo.h"
#import "HotKey.h"

#define TEXTOFFSET_LEFT 3
#define TEXTOFFSET_TOP  0

#define SMALLDELETEOFFSET_TOP 3
#define REGULARDELETEOFFSET_TOP 5
#define MINIDELETEOFFSET_TOP 2
#define DELETEOFFSET_RIGHT 3

#define KFREGULAR_HEIGHT	22
#define KFSMALL_HEIGHT		19
#define KFMINI_HEIGHT		15

typedef enum
{
	KFStyleRegular = 0,
	KFStyleSmall = 1,
	KFStyleMini = 2
} KFStyle;

@interface KeyCell : NSActionCell
{
	KeyCombo *_keyCombo;
	int _style;
	NSImage *keyRegularImage;
	NSImage *keySmallImage;
	NSImage *keyMiniImage;
}

- (void)setFieldStyle:(int)newStyle;
- (int)fieldStyle;

- (void)setKeyCombo:(KeyCombo *)combo;
- (KeyCombo *)keyCombo;

@end

@interface KeyField : NSControl
{	
	BOOL _isFirstResponder;
	NSButton *deleteButton;
	KeyCombo *_keyCombo;
	int _style;
	int _lastModifiers;
	
	HotKey *_hotKey;
	NSString *_autosaveName;
	BOOL _autoregister;
}

- (void)setFieldStyle:(int)newStyle;
- (int)fieldStyle;

- (void)setKeyCombo:(KeyCombo *)combo;
- (KeyCombo *)keyCombo;

- (HotKey *)hotKey;

- (void)setKeyComboAutosaveName:(NSString *)aName;
- (NSString *)keyComboAutosaveName;

- (void)setAutoregister:(BOOL)aAutoregister;
- (BOOL)autoregister;

@end
